pub struct PartialDate {
pub date_parts: DateParts,
}Expand description
represents an incomplete date only consisting of year or year and month
Fields
date_parts: DatePartsContains an ordered array of year, month, day of month.
Only year is required
e.g. [ [2006] ] to conform to citeproc JSON dates
Implementations
Sourceimpl PartialDate
impl PartialDate
Sourcepub fn as_date_field(&self) -> Option<DateField>
pub fn as_date_field(&self) -> Option<DateField>
converts the nested array of numbers into the correct representation of chrono NaiveDate