pub type Relations = HashMap<String, Value>;Expand description
A hashmap containing relation name, Relation pairs.
crossref rest-api-doc
However it seems, that the value of the relation name can also be an array.
Therefor the serde_json::Value type is used instead to prevent an invalid length error
Aliased Type
pub struct Relations { /* private fields */ }